Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(516)

Unified Diff: third_party/WebKit/Source/core/frame/DOMWindow.h

Issue 2769263004: Remove Frame::host() method (Closed)
Patch Set: Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/core/frame/DOMWindow.h
diff --git a/third_party/WebKit/Source/core/frame/DOMWindow.h b/third_party/WebKit/Source/core/frame/DOMWindow.h
index ece85b343f7e3d06f511b2fd74e6345a010fcbf0..8099170901faa6df18ec4a66e4db9290d6d6c181 100644
--- a/third_party/WebKit/Source/core/frame/DOMWindow.h
+++ b/third_party/WebKit/Source/core/frame/DOMWindow.h
@@ -36,13 +36,13 @@ class CORE_EXPORT DOMWindow : public EventTargetWithInlineData,
// - |m_frame->domWindow()| must point back to this DOMWindow. If it does
// not, it is easy to introduce a bug where script execution uses the
// wrong DOMWindow (which may be cross-origin).
// - |m_frame| must be attached, i.e. |m_frame->host()| must not be null.
// If |m_frame->host()| is null, this indicates a bug where the frame was
// detached but |m_frame| was not set to null. This bug can lead to
// issues where executing script incorrectly schedules work on a detached
// frame.
SECURITY_DCHECK(!m_frame ||
- (m_frame->domWindow() == this && m_frame->host()));
+ (m_frame->domWindow() == this && m_frame->page()));
return m_frame;
}
@@ -36,13 +36,13 @@ class CORE_EXPORT DOMWindow : public EventTargetWithInlineData,
// not, it is easy to introduce a bug where script execution uses the
// wrong DOMWindow (which may be cross-origin).
- // - |m_frame| must be attached, i.e. |m_frame->host()| must not be null.
- // If |m_frame->host()| is null, this indicates a bug where the frame was
+ // - |m_frame| must be attached, i.e. |m_frame->page()| must not be null.
+ // If |m_frame->page()| is null, this indicates a bug where the frame was
// detached but |m_frame| was not set to null. This bug can lead to
// issues where executing script incorrectly schedules work on a detached

Powered by Google App Engine
This is Rietveld 408576698